# python-deprecate
[![Build Status](https://travis-ci.org/mfalesni/python-deprecate.svg)](https://travis-ci.org/mfalesni/python-deprecate) [![Coverage Status](https://coveralls.io/repos/mfalesni/python-deprecate/badge.svg)](https://coveralls.io/r/mfalesni/python-deprecate)

A module providing `deprecated` decorator

License
=======
Licensed under both [GPLv3](LICENSE-GPLv3) and [MPL 2.0](LICENSE-MPL) (without Exhibit B).
